@@ -24,7 +24,7 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
     required_field = "webhook"
     author = "Mo"
     author_url = "https://github.com/M-Davinci/dt_notify_to_people"
-    version = "1.8.6"
+    version = "1.8.7"
     resource_links = [
         ("Report Issue", "https://github.com/M-Davinci/dt_notify_to_people/issues"),
         ("View Source", "https://github.com/M-Davinci/dt_notify_to_people"),
@@ -172,8 +172,8 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
             }
 
         }
-        # 0 - 状态为未解决，并且次数大于设定值，才告警通知
-        if group.status == 0 and group.times_seen > number_alarm:
+        # 0 - 状态为未解决，并且次数大于设定值，才告警通知，并且分配为空
+        if group.status == 0 and group.times_seen > number_alarm and not bool(event.data):
             for webhook_url in self.get_webhook_urls(group.project):
                 requests.post(webhook_url, data=json.dumps(data_1), headers=headers)
 
